@@ -56,6 +56,7 @@ class GoogleAPIResource(Resource):
         # Set some defaults
         self._service = None
         self._resource_metadata = None
+        self._full_resource_name = None
 
         # Load and validate additional resource data
         self._resource_data = resource_data
@@ -96,6 +97,9 @@ class GoogleAPIResource(Resource):
 
             #  NodePools
             'cluster': r'/clusters/([^\/]+)/',
+
+            # ServiceAccounts
+            'service_account': r'serviceAccounts/([^\/]+)/',
         }
 
         resource_data = {}
@@ -164,6 +168,12 @@ class GoogleAPIResource(Resource):
     def type(self):
         return self.resource_type
 
+    def full_resource_name(self):
+        if self._full_resource_name is None:
+            self.gen_full_resource_name()
+
+        return self._full_resource_name
+
     # Google's documentation describes what it calls a 'full resource name' for
     # resources. None of the API's seem to implement it (except Cloud Asset
     # Inventory). This attempts to generate it from the discovery-based api
@@ -171,7 +181,7 @@ class GoogleAPIResource(Resource):
     #
     # If we inject it into the resource, we can use it in policy evaluation to
     # simplify the structure of our policies
-    def full_resource_name(self):
+    def gen_full_resource_name(self):
 
         method = getattr(self.service, self.get_method)
         uri = method(**self._get_request_args()).uri
@@ -233,7 +243,7 @@ class GoogleAPIResource(Resource):
 
         resource_path = "/".join(path_segments)
 
-        return "//{}.googleapis.com/{}".format(api_name, resource_path)
+        self._full_resource_name = "//{}.googleapis.com/{}".format(api_name, resource_path)
 
     def _get_component(self, component):
         method_name = self.resource_components[component]
@@ -244,12 +254,11 @@ class GoogleAPIResource(Resource):
             req_arg_method = getattr(self, f'_get_{component}_request_args')
         else:
             req_arg_method = getattr(self, '_get_request_args')
-        
+
         method = getattr(self.service, method_name)
-        
+
         component_metadata = method(**req_arg_method()).execute()
         return component_metadata
-        
 
     def get(self, refresh=True):
 
@@ -382,7 +391,11 @@ class GoogleAPIResource(Resource):
 
     @property
     def labels(self):
-        return jmespath.search(self.resource_labels_path, self.get(refresh=False))
+        labels = jmespath.search(self.resource_labels_path, self.get(refresh=False)) or {}
+        if not isinstance(labels, dict):
+            raise TypeError("Unexpected label format")
+
+        return labels
 
     @property
     def project_id(self):
@@ -410,14 +423,12 @@ class GcpAppEngineInstance(GoogleAPIResource):
         }
 
 
-
 class GcpBigqueryDataset(GoogleAPIResource):
 
     service_name = "bigquery"
     resource_path = "datasets"
     version = "v2"
 
-
     required_resource_data = ['name', 'project_id']
 
     resource_type = "bigquery.googleapis.com/Dataset"
@@ -514,7 +525,7 @@ class GcpComputeInstance(GoogleAPIResource):
         }
 
 
-class GcpComputeDisks(GoogleAPIResource):
+class GcpComputeDisk(GoogleAPIResource):
 
     service_name = "compute"
     resource_path = "disks"
@@ -532,6 +543,24 @@ class GcpComputeDisks(GoogleAPIResource):
         }
 
 
+class GcpComputeRegionDisk(GoogleAPIResource):
+
+    service_name = "compute"
+    resource_path = "regionDisks"
+    version = "v1"
+
+    required_resource_data = ['name', 'location', 'project_id']
+
+    resource_type = "compute.googleapis.com/RegionDisk"
+
+    def _get_request_args(self):
+        return {
+            'project': self._resource_data['project_id'],
+            'region': self._resource_data['location'],
+            'disk': self._resource_data['name']
+        }
+
+
 class GcpComputeSubnetwork(GoogleAPIResource):
 
     service_name = "compute"
@@ -567,7 +596,6 @@ class GcpComputeFirewall(GoogleAPIResource):
         }
 
 
-
 class GcpDataprocCluster(GoogleAPIResource):
     service_name = "dataproc"
     resource_path = "projects.regions.clusters"
@@ -642,7 +670,6 @@ class GcpGkeCluster(GoogleAPIResource):
         }
 
 
-
 class GcpGkeClusterNodepool(GoogleAPIResource):
 
     service_name = "container"
@@ -666,6 +693,43 @@ class GcpGkeClusterNodepool(GoogleAPIResource):
         }
 
 
+class GcpIamServiceAccount(GoogleAPIResource):
+
+    service_name = "iam"
+    resource_path = "projects.serviceAccounts"
+    version = "v1"
+
+    required_resource_data = ['name', 'project_id']
+
+    resource_type = 'iam.googleapis.com/ServiceAccount'
+
+    def _get_request_args(self):
+        return {
+            'name': 'projects/{}/serviceAccounts/{}'.format(
+                self._resource_data['project_id'],
+                self._resource_data['name']
+            )
+        }
+
+
+class GcpIamServiceAccountKey(GoogleAPIResource):
+
+    service_name = "iam"
+    resource_path = "projects.serviceAccounts.keys"
+    version = "v1"
+
+    required_resource_data = ['name', 'service_account', 'project_id']
+
+    resource_type = 'iam.googleapis.com/ServiceAccountKey'
+
+    def _get_request_args(self):
+        return {
+            'name': 'projects/{}/serviceAccounts/{}/keys/{}'.format(
+                self._resource_data['project_id'],
+                self._resource_data['service_account'],
+                self._resource_data['name']
+            )
+        }
 
 class GcpPubsubSubscription(GoogleAPIResource):
 
@@ -698,7 +762,6 @@ class GcpPubsubSubscription(GoogleAPIResource):
         }
 
 
-
 class GcpPubsubTopic(GoogleAPIResource):
 
     service_name = "pubsub"
@@ -730,7 +793,6 @@ class GcpPubsubTopic(GoogleAPIResource):
         }
 
 
-
 class GcpStorageBucket(GoogleAPIResource):
 
     service_name = "storage"
@@ -770,6 +832,7 @@ class GcpSqlInstance(GoogleAPIResource):
             'project': self._resource_data['project_id']
         }
 
+
 class GcpOrganization(GoogleAPIResource):
 
     service_name = "cloudresourcemanager"
